==> pygraspi_test-0.2.0.tar.gz: pygraspi_test-0.2.0/setup.py <==
from setuptools import setup
from setuptools.config.expand import find_packages

setup(
  name = 'pygraspi_test',         # How you named your package folder (MyLib)
  packages = ['src/pygraspi_test'],   # Chose the same as "name"
  version = '0.2.0',      # Start with a small number and increase it with every change you make
  license='Apache 2.0',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Testing out how setting up a pypi package is done correctly',   # Give a short description about your library
  author = 'Kevin E. Martinez Sanchez',                   # Type in your name
  author_email = 'kevin425.m@hotmail.com',      # Type in your E-Mail
  url = 'https://github.com/kkevinmartinezz/PyTest',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/kkevinmartinezz/PyTest/archive/refs/tags/v_02.tar.gz',    # I explain this later on
  keywords = ['testing', 'pygraspi', 'example'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'notebook',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',

    # 'License :: OSI Approved :: MIT',   # Again, pick a license

    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    # 'Programming Language :: Python :: 3.12.6',
  ],
)

==> pygraspi_test-0.2.1.tar.gz: pygraspi_test-0.2.1/setup.py <==
from setuptools import setup
from setuptools.config.expand import find_packages

setup(
  name = 'pygraspi_test',         # How you named your package folder (MyLib)
  packages = find_packages(),   # Chose the same as "name"
  version = '0.2.1',      # Start with a small number and increase it with every change you make
  license='Apache 2.0',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Testing out how setting up a pypi package is done correctly',   # Give a short description about your library
  author = 'Kevin E. Martinez Sanchez',                   # Type in your name
  author_email = 'kevin425.m@hotmail.com',      # Type in your E-Mail
  url = 'https://github.com/kkevinmartinezz/PyTest',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/kkevinmartinezz/PyTest/archive/refs/tags/v_02.1.tar.gz',    # I explain this later on
  keywords = ['testing', 'pygraspi', 'example'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'notebook',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',

    # 'License :: OSI Approved :: MIT',   # Again, pick a license

    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    # 'Programming Language :: Python :: 3.12.6',
  ],
)
